@@ -37,7 +37,9 @@
 #define __PDSCN_H__
 
 
+#include <pds/pdscnglobal.h>
 #include <pds/pdscomplex.h>
+#include <pds/pdsquaternion.h>
 
 
 #endif /* __PDSCN_H__ */
