@@ -20,7 +20,7 @@
  * 
  */
 
-/** \file testprograma.c
+/** \example testprograma.c
  *  \author Fernando Pujaico Rivera
  *  \date 01-05-2015
  *  \brief Programa para el testeo de operaciones con números complejos.
@@ -33,16 +33,23 @@
 
 int main(int argc, char** argv)
 {
-	///////////////////////////////////////////////////////////////
-	PdsComplex a,b,c;
+    PdsComplex a,b,c;
+    PdsComplex d={3,4}; /* d=3.0+4.0 i */
 
-	a=_CRECT(1.5,2.0);
-	printf("  a:\t%f+%fi\n",a.Real,a.Imag);
-	b=_CRECT(3.0,-1.0);
-	printf("  b:\t%f+%fi\n",b.Real,b.Imag);
-	c=_CMULC(a,b);
+    /* a=1.5+2.0 i */
+    a=PDS_CRECT(1.5,2.0);
 
-	printf("a*b:\t%f+%fi\n",c.Real,c.Imag);
+    /* b=3.0-1.0 i */
+    b=PDS_CRECT(3.0,-1.0);
 
-	return EXIT_SUCCESS;
+    /* c=a*b */
+    c=PDS_CMULC(a,b);
+
+    /* Showing results */
+    printf("  a:\t%f+%fi\n",a.Real,a.Imag);
+    printf("  b:\t%f+%fi\n",b.Real,b.Imag);
+    printf("a*b:\t%f+%fi\n",c.Real,c.Imag);
+    printf("  d:\t%f+%fi\n",d.Real,d.Imag);
+
+    return EXIT_SUCCESS;
 }
